Documentation
¶
Index ¶
- Constants
- func IfElse[T any](condition bool, result, alternative T) T
- func Render(w io.Writer, node Node) error
- type Element
- type KV
- type Node
- func A(args ...any) Node
- func Abbr(args ...any) Node
- func Address(args ...any) Node
- func Area(attrs ...KV) Node
- func Article(args ...any) Node
- func Aside(args ...any) Node
- func Audio(args ...any) Node
- func B(args ...any) Node
- func Base(attrs ...KV) Node
- func Bdi(args ...any) Node
- func Bdo(args ...any) Node
- func Blockquote(args ...any) Node
- func Body(args ...any) Node
- func Br(attrs ...KV) Node
- func Button(args ...any) Node
- func Canvas(args ...any) Node
- func Caption(args ...any) Node
- func Cite(args ...any) Node
- func Code(args ...any) Node
- func Col(attrs ...KV) Node
- func Colgroup(args ...any) Node
- func Data(args ...any) Node
- func Datalist(args ...any) Node
- func Dd(args ...any) Node
- func Del(args ...any) Node
- func Details(args ...any) Node
- func Dfn(args ...any) Node
- func Dialog(args ...any) Node
- func Div(args ...any) Node
- func Dl(args ...any) Node
- func DoctypeHtml() Node
- func Dt(args ...any) Node
- func Em(args ...any) Node
- func Embed(attrs ...KV) Node
- func Empty(args ...any) Node
- func Fencedframe(args ...any) Node
- func Fieldset(args ...any) Node
- func Figcaption(args ...any) Node
- func Figure(args ...any) Node
- func Footer(args ...any) Node
- func Form(args ...any) Node
- func H1(args ...any) Node
- func H2(args ...any) Node
- func H3(args ...any) Node
- func H4(args ...any) Node
- func H5(args ...any) Node
- func H6(args ...any) Node
- func Head(args ...any) Node
- func Header(args ...any) Node
- func Hgroup(args ...any) Node
- func Hr(attrs ...KV) Node
- func Html(args ...any) Node
- func I(args ...any) Node
- func If(condition bool, result Node) Node
- func Iframe(args ...any) Node
- func Img(attrs ...KV) Node
- func Input(attrs ...KV) Node
- func Ins(args ...any) Node
- func Kbd(args ...any) Node
- func Label(args ...any) Node
- func Legend(args ...any) Node
- func Li(args ...any) Node
- func Link(attrs ...KV) Node
- func Main(args ...any) Node
- func Map(args ...any) Node
- func MapSlice[T any](input []T, f func(T) Node) Node
- func Mark(args ...any) Node
- func Math(args ...any) Node
- func Menu(args ...any) Node
- func Meta(attrs ...KV) Node
- func Meter(args ...any) Node
- func Nav(args ...any) Node
- func Noscript(args ...any) Node
- func Object(args ...any) Node
- func Ol(args ...any) Node
- func Optgroup(args ...any) Node
- func Option(args ...any) Node
- func Output(args ...any) Node
- func P(args ...any) Node
- func Picture(args ...any) Node
- func Pre(args ...any) Node
- func Progress(args ...any) Node
- func Q(args ...any) Node
- func Repeat(n int, f func() Node) Node
- func Rp(args ...any) Node
- func Rt(args ...any) Node
- func Ruby(args ...any) Node
- func S(args ...any) Node
- func Samp(args ...any) Node
- func Script(args ...any) Node
- func Search(args ...any) Node
- func Section(args ...any) Node
- func Select(args ...any) Node
- func Selectedcontent(args ...any) Node
- func Slot(args ...any) Node
- func Small(args ...any) Node
- func Source(attrs ...KV) Node
- func Span(args ...any) Node
- func Strong(args ...any) Node
- func Style(args ...any) Node
- func Sub(args ...any) Node
- func Summary(args ...any) Node
- func Sup(args ...any) Node
- func Svg(args ...any) Node
- func Table(args ...any) Node
- func Tbody(args ...any) Node
- func Td(args ...any) Node
- func Template(args ...any) Node
- func Textarea(args ...any) Node
- func Tfoot(args ...any) Node
- func Th(args ...any) Node
- func Thead(args ...any) Node
- func Time(args ...any) Node
- func Title(args ...any) Node
- func Tr(args ...any) Node
- func Track(attrs ...KV) Node
- func U(args ...any) Node
- func Ul(args ...any) Node
- func Var(args ...any) Node
- func Video(args ...any) Node
- func Wbr(attrs ...KV) Node
- type RawText
- type Text
Constants ¶
const ( AttrAccept = "accept" AttrAcceptCharset = "accept-charset" AttrAccessKey = "accesskey" AttrAction = "action" AttrAlign = "align" AttrAllow = "allow" AttrAlpha = "alpha" AttrAlt = "alt" AttrAs = "as" AttrAsync = "async" AttrAutocapitalize = "autocapitalize" AttrAutocomplete = "autocomplete" AttrAutofocus = "autofocus" AttrAutoplay = "autoplay" AttrBackground = "background" AttrBgColor = "bgcolor" AttrBorder = "border" AttrCapture = "capture" AttrCharset = "charset" AttrChecked = "checked" AttrCite = "cite" AttrClass = "class" AttrColor = "color" AttrColorSpace = "colorspace" AttrCols = "cols" AttrColSpan = "colspan" AttrContent = "content" AttrContentEditable = "contenteditable" AttrControls = "controls" AttrCoords = "coords" AttrCrossOrigin = "crossorigin" AttrCsp = "csp" AttrData = "data" AttrDateTime = "datetime" AttrDecoding = "decoding" AttrDefault = "default" AttrDefer = "defer" AttrDir = "dir" AttrDirName = "dirname" AttrDisabled = "disabled" AttrDownload = "download" AttrDraggable = "draggable" AttrEnctype = "enctype" AttrEnterKeyHint = "enterkeyhint" AttrElementTiming = "elementtiming" AttrForm = "form" AttrFormAction = "formaction" AttrFormEnctype = "formenctype" AttrFormMethod = "formmethod" AttrFormNoValidate = "formnovalidate" AttrFormTarget = "formtarget" AttrFetchPriority = "fetchpriority" AttrHeaders = "headers" AttrHeight = "height" AttrHidden = "hidden" AttrHigh = "high" AttrHref = "href" AttrHrefLang = "hreflang" AttrHttpEquiv = "http-equiv" AttrID = "id" AttrIntegrity = "integrity" AttrInputMode = "inputmode" AttrIsMap = "ismap" AttrItemProp = "itemprop" AttrKind = "kind" AttrLabel = "label" AttrLang = "lang" AttrLanguage = "language" AttrLoading = "loading" AttrList = "list" AttrLoop = "loop" AttrLow = "low" AttrMax = "max" AttrMaxLength = "maxlength" AttrMinLength = "minlength" AttrMedia = "media" AttrMethod = "method" AttrMin = "min" AttrMultiple = "multiple" AttrMuted = "muted" AttrName = "name" AttrNoValidate = "novalidate" AttrOnAbort = "onAbort" AttrOnActivate = "onActivate" AttrOnAfterPrint = "onAfterPrint" AttrOnAfterUpdate = "onAfterUpdate" AttrOnBeforeActivate = "onBeforeActivate" AttrOnBeforeCopy = "onBeforeCopy" AttrOnBeforeCut = "onBeforeCut" AttrOnBeforeDeactivate = "onBeforeDeactivate" AttrOnBeforeEditFocus = "onBeforeEditFocus" AttrOnBeforePaste = "onBeforePaste" AttrOnBeforePrint = "onBeforePrint" AttrOnBeforeUnload = "onBeforeUnload" AttrOnBeforeUpdate = "onBeforeUpdate" AttrOnBegin = "onBegin" AttrOnBlur = "onBlur" AttrOnBounce = "onBounce" AttrOnCellChange = "onCellChange" AttrOnChange = "onChange" AttrOnClick = "onClick" AttrOnContextMenu = "onContextMenu" AttrOnControlSelect = "onControlSelect" AttrOnCopy = "onCopy" AttrOnCut = "onCut" AttrOnDataAvailable = "onDataAvailable" AttrOnDataSetChanged = "onDataSetChanged" AttrOnDataSetComplete = "onDataSetComplete" AttrOnDblClick = "onDblClick" AttrOnDeactivate = "onDeactivate" AttrOnDrag = "onDrag" AttrOnDragEnd = "onDragEnd" AttrOnDragLeave = "onDragLeave" AttrOnDragEnter = "onDragEnter" AttrOnDragOver = "onDragOver" AttrOnDragDrop = "onDragDrop" AttrOnDragStart = "onDragStart" AttrOnDrop = "onDrop" AttrOnEnd = "onEnd" AttrOnError = "onError" AttrOnErrorUpdate = "onErrorUpdate" AttrOnFilterChange = "onFilterChange" AttrOnFinish = "onFinish" AttrOnFocus = "onFocus" AttrOnFocusIn = "onFocusIn" AttrOnFocusOut = "onFocusOut" AttrOnHashChange = "onHashChange" AttrOnHelp = "onHelp" AttrOnInput = "onInput" AttrOnKeyDown = "onKeyDown" AttrOnKeyPress = "onKeyPress" AttrOnKeyUp = "onKeyUp" AttrOnLayoutComplete = "onLayoutComplete" AttrOnLoad = "onLoad" AttrOnLoseCapture = "onLoseCapture" AttrOnMediaComplete = "onMediaComplete" AttrOnMediaError = "onMediaError" AttrOnMessage = "onMessage" AttrOnMouseDown = "onMouseDown" AttrOnMouseEnter = "onMouseEnter" AttrOnMouseLeave = "onMouseLeave" AttrOnMouseMove = "onMouseMove" AttrOnMouseOut = "onMouseOut" AttrOnMouseOver = "onMouseOver" AttrOnMouseUp = "onMouseUp" AttrOnMouseWheel = "onMouseWheel" AttrOnMove = "onMove" AttrOnMoveEnd = "onMoveEnd" AttrOnMoveStart = "onMoveStart" AttrOnOffline = "onOffline" AttrOnOnline = "onOnline" AttrOnOutOfSync = "onOutOfSync" AttrOnPaste = "onPaste" AttrOnPause = "onPause" AttrOnPopState = "onPopState" AttrOnProgress = "onProgress" AttrOnPropertyChange = "onPropertyChange" AttrOnReadyStateChange = "onReadyStateChange" AttrOnRedo = "onRedo" AttrOnRepeat = "onRepeat" AttrOnReset = "onReset" AttrOnResize = "onResize" AttrOnResizeEnd = "onResizeEnd" AttrOnResizeStart = "onResizeStart" AttrOnResume = "onResume" AttrOnReverse = "onReverse" AttrOnRowsEnter = "onRowsEnter" AttrOnRowExit = "onRowExit" AttrOnRowDelete = "onRowDelete" AttrOnRowInserted = "onRowInserted" AttrOnScroll = "onScroll" AttrOnSeek = "onSeek" AttrOnSelect = "onSelect" AttrOnSelectionChange = "onSelectionChange" AttrOnSelectStart = "onSelectStart" AttrOnStart = "onStart" AttrOnStop = "onStop" AttrOnStorage = "onStorage" AttrOnSyncRestored = "onSyncRestored" AttrOnSubmit = "onSubmit" AttrOnTimeError = "onTimeError" AttrOnTrackChange = "onTrackChange" AttrOnUndo = "onUndo" AttrOnUnload = "onUnload" AttrOnURLFlip = "onURLFlip" AttrOpen = "open" AttrOptimum = "optimum" AttrPattern = "pattern" AttrPing = "ping" AttrPlaceholder = "placeholder" AttrPlaysInline = "playsinline" AttrPoster = "poster" AttrPopoverTargetAction = "popovertargetaction" AttrPreload = "preload" AttrReadonly = "readonly" AttrReferrerPolicy = "referrerpolicy" AttrRel = "rel" AttrRequired = "required" AttrReversed = "reversed" AttrRole = "role" AttrRows = "rows" AttrRowSpan = "rowspan" AttrSandbox = "sandbox" AttrScope = "scope" AttrSelected = "selected" AttrShape = "shape" AttrSize = "size" AttrSizes = "sizes" AttrSlot = "slot" AttrSpan = "span" AttrSpellCheck = "spellcheck" AttrSrc = "src" AttrSrcDoc = "srcdoc" AttrSrcLang = "srclang" AttrSrcSet = "srcset" AttrStart = "start" AttrStep = "step" AttrStyle = "style" AttrSummary = "summary" AttrTabIndex = "tabindex" AttrTarget = "target" AttrTitle = "title" AttrTranslate = "translate" AttrType = "type" AttrUseMap = "usemap" AttrValue = "value" AttrWidth = "width" AttrWrap = "wrap" )
Attr* constants provide compile-time safety for HTML attribute names. Using these constants prevents typos and enables LSP autocompletion.
const ( TypeText = "text" TypePassword = "password" TypeCheckbox = "checkbox" TypeRadio = "radio" TypeSubmit = "submit" TypeReset = "reset" TypeButton = "button" TypeFile = "file" TypeHidden = "hidden" TypeImage = "image" TypeColor = "color" TypeDate = "date" TypeDateTime = "datetime" TypeDateTimeLocal = "datetime-local" TypeEmail = "email" TypeMonth = "month" TypeNumber = "number" TypeRange = "range" TypeSearch = "search" TypeTel = "tel" TypeTime = "time" TypeUrl = "url" TypeWeek = "week" )
Type* constants are valid values for the type attribute on various elements.
const ( RelAlternate = "alternate" RelAuthor = "author" RelBookmark = "bookmark" RelCanonical = "canonical" RelCompressionDictionary = "compression-dictionary" RelDnsPrefetch = "dns-prefetch" RelExternal = "external" RelHelp = "help" RelIcon = "icon" RelLicense = "license" RelManifest = "manifest" RelModulePreload = "modulepreload" RelNext = "next" RelNoFollow = "nofollow" RelNoOpener = "noopener" RelNoReferrer = "noreferrer" RelOpener = "opener" RelPingback = "pingback" RelPreconnect = "preconnect" RelPrefetch = "prefetch" RelPreload = "preload" RelPrerender = "prerender" RelPrev = "prev" RelSearch = "search" RelStylesheet = "stylesheet" RelTag = "tag" )
Rel* constants are valid values for the rel attribute.
const ( TargetBlank = "_blank" TargetSelf = "_self" TargetParent = "_parent" TargetTop = "_top" TargetFramename = "framename" )
Target* constants are valid values for the target attribute.
const ( MethodGet = "get" MethodPost = "post" )
Method* constants are valid values for the method attribute on <form>.
const ( EnctypeUrlEncoded = "application/x-www-form-urlencoded" EnctypeMultipartForm = "multipart/form-data" EnctypePlainText = "text/plain" )
Enctype* constants are valid values for the enctype attribute on <form>.
const ( CrossOriginAnonymous = "anonymous" CrossOriginUseCredentials = "use-credentials" )
CrossOrigin* constants are valid values for the crossorigin attribute.
const ( DirLtr = "ltr" DirRtl = "rtl" DirAuto = "auto" )
Dir* constants are valid values for the dir attribute.
const ( TranslateYes = "yes" TranslateNo = "no" )
Translate* constants are valid values for the translate attribute.
const ( PreloadNone = "none" PreloadMetadata = "metadata" PreloadAuto = "auto" )
Preload* constants are valid values for the preload attribute on <audio> and <video>.
const ( LoadingLazy = "lazy" LoadingEager = "eager" )
Loading* constants are valid values for the loading attribute on <img> and <iframe>.
const ( DecodingAsync = "async" DecodingSync = "sync" DecodingAuto = "auto" )
Decoding* constants are valid values for the decoding attribute on <img>.
const ( ReferrerPolicyNoReferrer = "no-referrer" ReferrerPolicyNoReferrerWhenDowngrade = "no-referrer-when-downgrade" ReferrerPolicyOrigin = "origin" ReferrerPolicyOriginWhenCrossOrigin = "origin-when-cross-origin" ReferrerPolicySameOrigin = "same-origin" ReferrerPolicyStrictOriginWhenCrossOrigin = "strict-origin-when-cross-origin" ReferrerPolicyUnsafeUrl = "unsafe-url" )
ReferrerPolicy* constants are valid values for the referrerpolicy attribute.
const ( FetchPriorityLow = "low" FetchPriorityHigh = "high" FetchPriorityAuto = "auto" )
FetchPriority* constants are valid values for the fetchpriority attribute.
const ( EnterKeyHintEnter = "enter" EnterKeyHintDone = "done" EnterKeyHintGo = "go" EnterKeyHintNext = "next" EnterKeyHintPrevious = "previous" EnterKeyHintSearch = "search" EnterKeyHintSend = "send" )
EnterKeyHint* constants are valid values for the enterkeyhint attribute.
const ( WrapHard = "hard" WrapSoft = "soft" WrapOff = "off" )
Wrap* constants are valid values for the wrap attribute on <textarea>.
const ( ShapeDefault = "default" ShapeCircle = "circle" ShapePoly = "poly" ShapeRect = "rect" )
Shape* constants are valid values for the shape attribute on <area>.
const ( SpellCheckTrue = "true" SpellCheckFalse = "false" )
Spellcheck* constants are valid values for the spellcheck attribute.
const ( ContentEditableTrue = "true" ContentEditableFalse = "false" ContentEditablePlaintextOnly = "plaintext-only" )
ContentEditable* constants are valid values for the contenteditable attribute.
const ( DraggableTrue = "true" DraggableFalse = "false" )
Draggable* constants are valid values for the draggable attribute.
const ( InputModeNone = "none" InputModeText = "text" InputModeDecimal = "decimal" InputModeNumeric = "numeric" InputModeTel = "tel" InputModeSearch = "search" InputModeEmail = "email" InputModeUrl = "url" )
InputMode* constants are valid values for the inputmode attribute.
const ( PopoverTargetActionHide = "hide" PopoverTargetActionShow = "show" PopoverTargetActionToggle = "toggle" )
PopoverTargetAction* constants are valid values for the popovertargetaction attribute.
const ( AutocompleteOff = "off" AutocompleteOn = "on" AutocompleteName = "name" AutocompleteHonorificPrefix = "honorific-prefix" AutocompleteGivenName = "given-name" AutocompleteAdditionalName = "additional-name" AutocompleteFamilyName = "family-name" AutocompleteHonorificSuffix = "honorific-suffix" AutocompleteNickname = "nickname" AutocompleteEmail = "email" AutocompleteUsername = "username" AutocompleteNewPassword = "new-password" AutocompleteCurrentPassword = "current-password" AutocompleteOneTimeCode = "one-time-code" AutocompleteOrganizationTitle = "organization-title" AutocompleteOrganization = "organization" AutocompleteStreetAddress = "street-address" AutocompleteAddressLine1 = "address-line1" AutocompleteAddressLine2 = "address-line2" AutocompleteAddressLine3 = "address-line3" AutocompleteAddressLevel4 = "address-level4" AutocompleteAddressLevel3 = "address-level3" AutocompleteAddressLevel2 = "address-level2" AutocompleteAddressLevel1 = "address-level1" AutocompleteCountry = "country" AutocompleteCountryName = "country-name" AutocompleteCcName = "cc-name" AutocompleteCcGivenName = "cc-given-name" AutocompleteCcAdditionalName = "cc-additional-name" AutocompleteCcFamilyName = "cc-family-name" AutocompleteCcNumber = "cc-number" AutocompleteCcExp = "cc-exp" AutocompleteCcExpMonth = "cc-exp-month" AutocompleteCcExpYear = "cc-exp-year" AutocompleteCcCsc = "cc-csc" AutocompleteCcType = "cc-type" AutocompleteTransactionCurrency = "transaction-currency" AutocompleteTransactionAmount = "transaction-amount" AutocompleteLanguage = "language" AutocompleteBday = "bday" AutocompleteBdayDay = "bday-day" AutocompleteBdayMonth = "bday-month" AutocompleteBdayYear = "bday-year" AutocompleteSex = "sex" AutocompleteTelCountryCode = "tel-country-code" AutocompleteTelNational = "tel-national" AutocompleteTelAreaCode = "tel-area-code" AutocompleteTelLocal = "tel-local" AutocompleteTelExtension = "tel-extension" AutocompleteImpp = "impp" AutocompleteUrl = "url" AutocompletePhoto = "photo" )
Autocomplete* constants are valid values for the autocomplete attribute.
const ( SandboxAllowForms = "allow-forms" SandboxAllowModals = "allow-modals" SandboxAllowOrientationLock = "allow-orientation-lock" SandboxAllowPointerLock = "allow-pointer-lock" SandboxAllowPopups = "allow-popups" SandboxAllowPopupsToEscapeSandbox = "allow-popups-to-escape-sandbox" SandboxAllowPresentation = "allow-presentation" SandboxAllowSameOrigin = "allow-same-origin" SandboxAllowScripts = "allow-scripts" )
Sandbox* constants are valid values for the sandbox attribute on <iframe>.
const ( EventAbort = "abort" EventAfterPrint = "afterprint" EventAnimationEnd = "animationend" EventAnimationIteration = "animationiteration" EventAnimationStart = "animationstart" EventAppInstalled = "appinstalled" EventAudioProcess = "audioprocess" EventAudioEnd = "audioend" EventAudioStart = "audiostart" EventBeforePrint = "beforeprint" EventBeforeUnload = "beforeunload" EventBeginEvent = "beginEvent" EventBlur = "blur" EventBoundary = "boundary" EventCached = "cached" EventCanPlay = "canplay" EventCanPlayThrough = "canplaythrough" EventChange = "change" EventChargingChange = "chargingchange" EventChargingTimeChange = "chargingtimechange" EventChecking = "checking" EventClick = "click" EventClose = "close" EventComplete = "complete" EventCompositionEnd = "compositionend" EventCompositionStart = "compositionstart" EventCompositionUpdate = "compositionupdate" EventContextMenu = "contextmenu" EventCopy = "copy" EventCut = "cut" EventDblClick = "dblclick" EventDeviceChange = "devicechange" EventDeviceLight = "devicelight" EventDeviceMotion = "devicemotion" EventDeviceOrientation = "deviceorientation" EventDeviceProximity = "deviceproximity" EventDischargingTimeChange = "dischargingtimechange" EventDomActivate = "DOMActivate" EventDomAttributeNameChanged = "DOMAttributeNameChanged" EventDomAttrModified = "DOMAttrModified" EventDomCharacterDataModified = "DOMCharacterDataModified" EventDomContentLoaded = "DOMContentLoaded" EventDomElementNameChanged = "DOMElementNameChanged" EventDomFocusIn = "DOMFocusIn" EventDomFocusOut = "DOMFocusOut" EventDomNodeInserted = "DOMNodeInserted" EventDomNodeInsertedIntoDocument = "DOMNodeInsertedIntoDocument" EventDomNodeRemoved = "DOMNodeRemoved" EventDomNodeRemovedFromDocument = "DOMNodeRemovedFromDocument" EventDomSubtreeModified = "DOMSubtreeModified" EventDownloading = "downloading" EventDrag = "drag" EventDragEnd = "dragend" EventDragEnter = "dragenter" EventDragLeave = "dragleave" EventDragOver = "dragover" EventDragStart = "dragstart" EventDrop = "drop" EventDurationChange = "durationchange" EventEmptied = "emptied" EventEnd = "end" EventEnded = "ended" EventEndEvent = "endEvent" EventError = "error" EventFocus = "focus" EventFocusIn = "focusin" EventFocusOut = "focusout" EventFullscreenChange = "fullscreenchange" EventFullscreenError = "fullscreenerror" EventGamepadConnected = "gamepadconnected" EventGamepadDisconnected = "gamepaddisconnected" EventGotPointerCapture = "gotpointercapture" EventHashChange = "hashchange" EventLostPointerCapture = "lostpointercapture" EventInput = "input" EventInvalid = "invalid" EventKeyDown = "keydown" EventKeyPress = "keypress" EventKeyUp = "keyup" EventLanguageChange = "languagechange" EventLevelChange = "levelchange" EventLoad = "load" EventLoadedData = "loadeddata" EventLoadedMetadata = "loadedmetadata" EventLoadEnd = "loadend" EventLoadStart = "loadstart" EventMark = "mark" EventMessage = "message" EventMessageError = "messageerror" EventMouseDown = "mousedown" EventMouseEnter = "mouseenter" EventMouseLeave = "mouseleave" EventMouseMove = "mousemove" EventMouseOut = "mouseout" EventMouseOver = "mouseover" EventMouseUp = "mouseup" EventNoMatch = "nomatch" EventNotificationClick = "notificationclick" EventNoUpdate = "noupdate" EventObsolete = "obsolete" EventOffline = "offline" EventOnline = "online" EventOpen = "open" EventOrientationChange = "orientationchange" EventPageHide = "pagehide" EventPageShow = "pageshow" EventPaste = "paste" EventPause = "pause" EventPointerCancel = "pointercancel" EventPointerDown = "pointerdown" EventPointerEnter = "pointerenter" EventPointerLeave = "pointerleave" EventPointerLockChange = "pointerlockchange" EventPointerLockError = "pointerlockerror" EventPointerMove = "pointermove" EventPointerOut = "pointerout" EventPointerOver = "pointerover" EventPointerUp = "pointerup" EventPlay = "play" EventPlaying = "playing" EventPopState = "popstate" EventProgress = "progress" EventPush = "push" EventPushSubscriptionChange = "pushsubscriptionchange" EventRateChange = "ratechange" EventReadyStateChange = "readystatechange" EventRepeatEvent = "repeatEvent" EventReset = "reset" EventResize = "resize" EventResourceTimingBufferFull = "resourcetimingbufferfull" EventResult = "result" EventResume = "resume" EventScroll = "scroll" EventSeeked = "seeked" EventSeeking = "seeking" EventSelect = "select" EventSelectStart = "selectstart" EventSelectionChange = "selectionchange" EventShow = "show" EventSlotChange = "slotchange" EventSoundEnd = "soundend" EventSoundStart = "soundstart" EventSpeechEnd = "speechend" EventSpeechStart = "speechstart" EventStalled = "stalled" EventStart = "start" EventStorage = "storage" EventSubmit = "submit" EventSuccess = "success" EventSuspend = "suspend" EventSvgAbort = "SVGAbort" EventSvgError = "SVGError" EventSvgLoad = "SVGLoad" EventSvgResize = "SVGResize" EventSvgScroll = "SVGScroll" EventSvgUnload = "SVGUnload" EventSvgZoom = "SVGZoom" EventTimeout = "timeout" EventTimeUpdate = "timeupdate" EventTouchCancel = "touchcancel" EventTouchEnd = "touchend" EventTouchMove = "touchmove" EventTouchStart = "touchstart" EventTransitionEnd = "transitionend" EventUnload = "unload" EventUpdateReady = "updateready" EventUserProximity = "userproximity" EventVoicesChanged = "voiceschanged" EventVisibilityChange = "visibilitychange" EventVolumeChange = "volumechange" EventWaiting = "waiting" EventWheel = "wheel" )
Event* constants provide compile-time safety for HTML event names. Using these constants prevents typos and enables LSP autocompletion.
Variables ¶
This section is empty.
Functions ¶
func IfElse ¶
IfElse returns the appropriate value based on a boolean condition.
This generic function is useful for inline conditional expressions in builder-style code where you need to choose between two values without breaking the chain of method calls.
Example:
div := Div(KV{"class": IfElse(isActive, "active", "inactive")})
Body(
IfElse(isAdmin,
Div("Admin content"),
P("Regular user content"),
),
)
Types ¶
type Element ¶
type Element struct {
Tag string // HTML tag name
IsVoid bool // Whether the tag is self-closing (e.g., <br>, <img>)
Attributes []attribute // HTML attributes as key-value pairs
Children []Node // Child nodes
}
Element represents an HTML element with its attributes and children.
type KV ¶
KV represents a key-value map for HTML attributes.
The value type must be either string or bool:
- string: Attribute will have the format key="value" (HTML-escaped)
- bool: If true, attribute appears as key (valueless). If false, attribute is omitted.
- any other type triggers an error during rendering.
Example:
KV{"class": "container", "hidden": true, "disabled": false}
// Renders: class="container" hidden
type Node ¶
Node represents any renderable HTML element or text content.
The Node interface is the core abstraction that allows both HTML elements and text content to be treated uniformly when building and rendering HTML trees. All elements created by the factory functions (Div(), P(), Svg(), etc.) implement this interface.
Example:
var node Node = Div("Hello")
err := node.Render(os.Stdout)
func A ¶
A creates hyperlinks to other web pages, files, locations within the same page, or anything else a URL can address.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/a
func Abbr ¶
Abbr represents an abbreviation.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/abbr
func Address ¶
Address indicates contact information for a person or organization.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/address
func Area ¶
Area defines an area inside an image map that has predefined clickable areas. An image map allows geometric areas on an image to be associated with hyperlink.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/area
func Article ¶
Article creates an article element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/article
func Aside ¶
Aside creates an aside element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/aside
func Audio ¶
Audio is used to embed sound content in documents. It may contain one or more audio sources, represented using the src attribute or the source element: the browser will choose the most suitable one. It can also be the destination for streamed media, using a MediaStream.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/audio
func B ¶
B draws attention to text without conveying importance.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/b
func Base ¶
Base specifies the base URL and default browsing context for relative URLs.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/base
func Bdi ¶
Bdi isolates text for bidirectional text formatting.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/bdi
func Bdo ¶
Bdo overrides the current text direction.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/bdo
func Blockquote ¶
Blockquote represents a section quoted from another source.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/blockquote
func Body ¶
Body represents the content of an HTML document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/body
func Br ¶
Br produces a line break in text (carriage-return). It is useful for writing a poem or an address, where the division of lines is significant.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/br
func Button ¶
Button is an interactive element activated by a user with a mouse, keyboard, finger, voice command, or other assistive technology. Once activated, it performs an action, such as submitting a form or opening a dialog.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/button
func Canvas ¶
Canvas is a container element to use with either the canvas scripting API or the WebGL API to draw graphics and animations.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/canvas
func Caption ¶
Caption specifies the caption (or title) of a table.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/caption
func Cite ¶
Cite marks the title of a creative work.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/cite
func Code ¶
Code displays its contents styled as computer code.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/code
func Col ¶
Col defines one or more columns in a column group represented by its implicit or explicit parent <colgroup> element. The <col> element is only valid as a child of a <colgroup> element that has no span attribute defined.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/col
func Colgroup ¶
Colgroup defines a group of columns within a table.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/colgroup
func Data ¶
Data links content with a machine-readable translation.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/data
func Datalist ¶
Datalist contains a set of <option> elements that represent the permissible or recommended options available to choose from within other controls.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/datalist
func Dd ¶
Dd provides the description, definition, or value for the preceding term.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/dd
func Del ¶
Del represents a range of text that has been deleted from a document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/del
func Details ¶
Details creates a disclosure widget in which information is visible only when the widget is toggled into an "open" state. A summary or label must be provided using the <summary> element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/details
func Dfn ¶
Dfn indicates the defining instance of a term.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/dfn
func Dialog ¶
Dialog represents a dialog box or other interactive component, such as a dismissible alert, inspector, or subwindow.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/dialog
func Div ¶
Div is the generic container for flow content.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/div
func Dl ¶
Dl represents a description list.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/dl
func Dt ¶
Dt specifies a term in a description or definition list.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/dt
func Em ¶
Em marks text with emphasis.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/em
func Embed ¶
Embed embeds external content at the specified point in the document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/embed
func Fencedframe ¶
Fencedframe represents a nested browsing context, like <iframe> but with more native privacy features built in.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/fencedframe
func Fieldset ¶
Fieldset is used to group several controls as well as labels (<label>) within a web form.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/fieldset
func Figcaption ¶
Figcaption represents a caption or legend for the contents of its parent figure element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/figcaption
func Figure ¶
Figure represents self-contained content with an optional caption.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/figure
func Footer ¶
Footer creates a footer element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/footer
func Form ¶
Form represents a document section containing interactive controls for submitting information.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/form
func H1 ¶
H1 creates a level 1 heading element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/h1
func H2 ¶
H2 creates a level 2 heading element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/h2
func H3 ¶
H3 creates a level 3 heading element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/h3
func H4 ¶
H4 creates a level 4 heading element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/h4
func H5 ¶
H5 creates a level 5 heading element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/h5
func H6 ¶
H6 creates a level 6 heading element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/h6
func Head ¶
Head contains machine-readable information about the document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/head
func Header ¶
Header creates a header element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/header
func Hgroup ¶
Hgroup groups a set of h1–h6 elements when they represent a multi-level heading.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/hgroup
func Hr ¶
Hr represents a thematic break between paragraph-level elements.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/hr
func Html ¶
Html creates the root element of an HTML document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/html
func I ¶
I represents text in an alternate voice or mood.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/i
func If ¶
Conditionally returns a Node based on a boolean condition.
This function returns an empty Node (not nil) when the condition is false, which prevents nil pointer issues when building DOM trees.
Example:
Body( If(showHeader, Header(...)), Main(...), )
func Iframe ¶
Iframe represents a nested browsing context, embedding another HTML page into the current one.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/iframe
func Img ¶
Img embeds an image into the document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/img
func Input ¶
Input is used to create interactive controls for web-based forms to accept data from the user; a wide variety of types of input data and control widgets are available, depending on the device and user agent. The <input> element is one of the most powerful and complex in all of HTML due to the sheer number of combinations of input types and attributes.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/input
func Ins ¶
Ins represents a range of text that has been added to a document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/ins
func Kbd ¶
Kbd represents text that the user should enter.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/kbd
func Label ¶
Label represents a caption for an item in a user interface.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/label
func Legend ¶
Legend represents a caption for the content of its parent <fieldset>.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/legend
func Li ¶
Li represents a list item.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/li
func Link ¶
Link specifies relationships between the current document and an external resource.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/link
func Main ¶
Main creates a main content element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/main
func Map ¶
Map is used with <area> elements to define an image map (a clickable link area).
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/map
func MapSlice ¶
MapSlice transforms a slice of items into Nodes by applying a function to each element.
Each element in the input slice is transformed using the provided function, and all resulting Nodes are aggregated into a single container Node.
Example:
items := []string{"Apple", "Banana", "Cherry"}
Ul(
MapSlice(items, func(item string) Node {
return Li(item)
}),
)
func Mark ¶
Mark highlights text for reference.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/mark
func Math ¶
Math is the top-level element in MathML. Every valid MathML instance must be wrapped in it. In addition, you must not nest a second <math> element in another, but you can have an arbitrary number of other child elements in it.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/math
func Menu ¶
Menu represents a set of commands or options.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/menu
func Meta ¶
Meta represents metadata that cannot be represented by other HTML meta-related elements.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/meta
func Meter ¶
Meter represents either a scalar value within a known range or a fractional value.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/meter
func Nav ¶
Nav creates a navigation element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/nav
func Noscript ¶
Noscript defines a section of HTML to be inserted if a script type on the page is unsupported or if scripting is currently turned off in the browser.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/noscript
func Object ¶
Object represents an external resource, which can be treated as an image, a nested browsing context, or a resource to be handled by a plugin.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/object
func Ol ¶
Ol represents an ordered list.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/ol
func Optgroup ¶
Optgroup creates a grouping of options within a <select> element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/optgroup
func Option ¶
Option is used to define an item contained in a <select>, an <optgroup>, or a <datalist> element. As such, <option> can represent menu items in popups and other lists of items in an HTML document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/option
func Output ¶
Output is a container element into which a site or app can inject the results of a calculation or the outcome of a user action.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/output
func P ¶
P creates a paragraph element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/p
func Picture ¶
Picture defines multiple sources for an img element to offer alternative versions of an image for different display/device scenarios.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/picture
func Pre ¶
Pre represents preformatted text.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/pre
func Progress ¶
Progress displays an indicator showing the completion progress of a task, typically displayed as a progress bar.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/progress
func Q ¶
Q indicates a short inline quotation.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/q
func Repeat ¶
Repeat generates multiple Nodes by calling a function n times.
The provided function is called exactly n times, and each resulting Node is aggregated into a single container Node. Using a function ensures each Node instance is unique (important for elements with mutable state).
Example:
Ul(
Repeat(5, func() Node {
return Li("List item")
}),
)
func Rp ¶
Rp provides parentheses for browsers that don't support ruby text.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/rp
func Rt ¶
Rt specifies the ruby text for ruby annotations.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/rt
func Ruby ¶
Ruby represents ruby annotations for East Asian typography.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/ruby
func S ¶
S renders text with a strikethrough.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/s
func Samp ¶
Samp represents sample output from a computer program.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/samp
func Script ¶
Script is used to embed executable code or data; this is typically used to embed or refer to JavaScript code. The <script> element can also be used with other languages, such as WebGL's GLSL shader programming language and JSON.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/script
func Search ¶
Search represents a search or filtering interface.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/search
func Section ¶
Section creates a section element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/section
func Select ¶
Select represents a control that provides a menu of options.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/select
func Selectedcontent ¶
Selectedcontent displays the content of the currently selected <option> inside a closed <select> element.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/selectedcontent
func Slot ¶
Slot acts as a placeholder inside a web component that you can fill with your own markup, which lets you create separate DOM trees and present them together.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/slot
func Small ¶
Small represents side-comments and small print.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/small
func Source ¶
Source specifies multiple media resources for the picture, the audio element, or the video element. It is a void element, meaning that it has no content and does not have a closing tag. It is commonly used to offer the same media content in multiple file formats in order to provide compatibility with a broad range of browsers given their differing support for image file formats and media file formats.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/source
func Span ¶
Span is the generic inline container for phrasing content.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/span
func Strong ¶
Strong indicates strong importance.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/strong
func Style ¶
Style contains style information for a document or part of a document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/style
func Sub ¶
Sub specifies inline text displayed as subscript.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/sub
func Summary ¶
Summary specifies a summary, caption, or legend for a details element's disclosure box. Clicking the <summary> element toggles the state of the parent <details> element open and closed.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/summary
func Sup ¶
Sup specifies inline text displayed as superscript.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/sup
func Svg ¶
Svg is a container defining a new coordinate system and viewport. It is used as the outermost element of SVG documents, but it can also be used to embed an SVG fragment inside an SVG or HTML document.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/svg
func Table ¶
Table represents tabular data—that is, information presented in a two-dimensional table comprised of rows and columns of cells containing data.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/table
func Tbody ¶
Tbody groups the body content in a table with information about the table's columns. This is usually in the form of column headers (<th> elements).
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/tbody
func Td ¶
Td is a child of the <tr> element, it defines a cell of a table that contains data.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/td
func Template ¶
Template holds HTML that is not to be rendered immediately when a page is loaded but may be instantiated subsequently during runtime using JavaScript.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/template
func Textarea ¶
Textarea represents a multi-line plain-text editing control, useful when you want to allow users to enter a sizeable amount of free-form text, for example, a comment on a review or feedback form.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/textarea
func Tfoot ¶
Tfoot groups the footer content in a table with information about the table's columns. This is usually a summary of the columns, e.g., a sum of the given numbers in a column.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/tfoot
func Th ¶
Th is a child of the <tr> element, it defines a cell as the header of a group of table cells. The nature of this group can be explicitly defined by the scope and headers attributes.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/th
func Thead ¶
Thead groups the header content in a table with information about the table's columns. This is usually in the form of column headers (<th> elements).
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/thead
func Time ¶
Time represents a specific period in time.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/time
func Title ¶
Title defines the document's title that is shown in a browser's title bar or a page's tab.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/title
func Tr ¶
Tr defines a row of cells in a table. The row's cells can then be established using a mix of <td> (data cell) and <th> (header cell) elements.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/tr
func Track ¶
Track is used as a child of the media elements, audio and video. It lets you specify timed text tracks (or time-based data), for example to automatically handle subtitles. The tracks are formatted in WebVTT format (.vtt files)—Web Video Text Tracks.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/track
func U ¶
U represents text with an unarticulated annotation.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/u
func Ul ¶
Ul represents an unordered list.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/ul
func Var ¶
Var represents a variable in a mathematical expression or programming context.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/var
func Video ¶
Video embeds a media player which supports video playback into the document. You can also use <video> for audio content, but the audio element may provide a more appropriate user experience.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/video
func Wbr ¶
Wbr represents a word break opportunity.
https://developer.mozilla.org/en-US/docs/Web/HTML/Reference/Elements/wbr
Directories
¶
| Path | Synopsis |
|---|---|
|
examples
|
|
|
login_form
command
|
|
|
simple_page
command
|
|
|
templ: version: v0.3.977
|
templ: version: v0.3.977 |